powered by
Verify that the two matrices share the same time values and the same states.
.compute_validatePair(res_mat1, res_mat2)
Trajectory matrix 1, first column must be time while others are states.
Trajectory matrix 2, first column must be time while others are states.
# Internal only; error if check fails.
Run the code above in your browser using DataLab